import { Component, Input, EventEmitter, HostListener, Output } from '@angular/core';
import { stopPropagationIfExist } from '../utils/dom-utils';
import { trigger, state, style, animate, transition } from '@angular/animations';
var ActionButtonComponent = (function () {
    function ActionButtonComponent() {
        this.type = 'default';
        this.direction = 'down';
        this.disabled = false;
        this.actionClick = new EventEmitter();
        this.openStatusChange = new EventEmitter();
        this.animateState = 'initial';
        this.isOpen = false;
    }
    ActionButtonComponent.prototype.toggle = function ($event) {
        stopPropagationIfExist($event);
        if (!this.isOpen) {
            this.show();
        }
        else {
            this.hide();
        }
        this.openStatusChange.emit(this.isOpen);
    };
    ActionButtonComponent.prototype.afterVisibilityAnimation = function (e) {
        if (e.toState === 'hidden' && this.isOpen) {
            this.isOpen = false;
        }
    };
    ActionButtonComponent.prototype.close = function () {
        if (this.isOpen) {
            this.hide();
            this.openStatusChange.emit(this.isOpen);
        }
    };
    ActionButtonComponent.prototype.onActionClick = function (item) {
        if (!item.disabled) {
            this.close();
            this.actionClick.emit(item);
        }
    };
    ActionButtonComponent.prototype.show = function () {
        this.isOpen = true;
        this.animateState = 'visible';
    };
    ActionButtonComponent.prototype.hide = function () {
        this.animateState = 'hidden';
    };
    return ActionButtonComponent;
}());
export { ActionButtonComponent };
ActionButtonComponent.decorators = [
    { type: Component, args: [{
                selector: 're-action-button',
                template: "\n    <ng-template #defaultButtonTemplate let-action>\n      <button class=\"btn {{action.type? 'btn-' + action.type : ''}} {{action.btnSize? 'btn-' + action.btnSize : ''}}\"\n              (click)=\"action.toggle($event)\"\n              [disabled]=\"action.disabled\">\n        <i *ngIf=\"action.icon\" class=\"{{action.icon}}\" aria-hidden=\"true\"></i>\n        {{action.buttonText}}\n      </button>\n      <button type=\"button\"\n              class=\"btn {{action.type? 'btn-' + action.type : ''}} {{action.btnSize? 'btn-' + action.btnSize : ''}} dropdown-toggle\"\n              aria-haspopup=\"true\"\n              [attr.aria-expanded]=\"true\"\n              (click)=\"action.toggle($event)\" [disabled]=\"action.disabled\">\n        <span class=\"caret\"></span>\n        <span class=\"sr-only\">|</span>\n      </button>\n    </ng-template>\n\n    <div class=\"btn-group {{direction? 'drop' + direction : '' }} {{cssClass}}\" [ngClass]=\"{open: isOpen}\">\n\n      <ng-template [ngTemplateOutlet]=\"buttonTemplate || defaultButtonTemplate\"\n                   [ngOutletContext]=\"{ $implicit: this}\"></ng-template>\n\n      <ul class=\"dropdown-menu\" role=\"menu\" [@state]=\"animateState\" (@state.done)=\"afterVisibilityAnimation($event)\">\n        <ng-container *ngFor=\"let item of actions\">\n          <li *ngIf=\"!item.divider && ! item.header\" role=\"menuitem\" [ngClass]=\"{'disabled': item.disabled}\"\n              (click)=\"onActionClick(item)\">\n            <a><i *ngIf=\"item.icon\" class=\"{{item.icon}}\"></i>&nbsp;{{item.text}}</a></li>\n          <li *ngIf=\"item.header\" class=\"dropdown-header\">{{item.text}}</li>\n          <li *ngIf=\"item.divider\" class=\"divider\" role=\"separator\"></li>\n        </ng-container>\n      </ul>\n    </div>\n  ",
                exportAs: 'actionButton',
                animations: [
                    trigger('state', [
                        state('void', style({ transform: 'scale(0)' })),
                        state('initial', style({ transform: 'scale(0)' })),
                        state('visible', style({ transform: 'scale(1)' })),
                        state('hidden', style({ transform: 'scale(0)' })),
                        transition('* => visible', animate('150ms cubic-bezier(0.0, 0.0, 0.2, 1)')),
                        transition('* => hidden', animate('150ms cubic-bezier(0.4, 0.0, 1, 1)')),
                    ])
                ]
            },] },
];
/** @nocollapse */
ActionButtonComponent.ctorParameters = function () { return []; };
ActionButtonComponent.propDecorators = {
    'type': [{ type: Input },],
    'direction': [{ type: Input },],
    'icon': [{ type: Input },],
    'btnSize': [{ type: Input },],
    'buttonText': [{ type: Input },],
    'cssClass': [{ type: Input },],
    'actions': [{ type: Input },],
    'disabled': [{ type: Input },],
    'buttonTemplate': [{ type: Input },],
    'actionClick': [{ type: Output },],
    'openStatusChange': [{ type: Output },],
    'close': [{ type: HostListener, args: ['document:click', ['$event'],] },],
};
//# sourceMappingURL=action-button.component.js.map