import { Component, ChangeDetectionStrategy, Input, ChangeDetectorRef, forwardRef } from '@angular/core';
import { RebirthNGConfig } from '../rebirth-ng.config';
import { NG_VALUE_ACCESSOR } from '@angular/forms';
var CheckboxGroupComponent = (function () {
    function CheckboxGroupComponent(rebirthNGConfig, changeDetectorRef) {
        this.changeDetectorRef = changeDetectorRef;
        this.disabled = false;
        this.value = [];
        this.onChange = function (_) { return null; };
        this.onTouched = function () { return null; };
        this.formatter = rebirthNGConfig.checkboxGroup.formatter;
        this.valueParser = rebirthNGConfig.checkboxGroup.valueParser;
    }
    CheckboxGroupComponent.prototype.writeValue = function (obj) {
        this.value = obj instanceof Array ? obj : (obj ? [obj] : []);
        this.changeDetectorRef.markForCheck();
    };
    CheckboxGroupComponent.prototype.registerOnChange = function (fn) {
        this.onChange = fn;
    };
    CheckboxGroupComponent.prototype.registerOnTouched = function (fn) {
        this.onTouched = fn;
    };
    CheckboxGroupComponent.prototype.setDisabledState = function (isDisabled) {
        this.disabled = isDisabled;
    };
    CheckboxGroupComponent.prototype.onCheckBoxChange = function (item, checkbox) {
        this.onTouched();
        this.value = this.value || [];
        var value = this.valueParser(item);
        if (checkbox.checked) {
            this.value = this.value.concat([value]);
        }
        else {
            this.value = this.value.filter(function (valueItem) { return valueItem !== value; });
        }
        this.onChange(this.value);
    };
    CheckboxGroupComponent.prototype.isChecked = function (item) {
        return this.value.indexOf(this.valueParser(item)) !== -1;
    };
    return CheckboxGroupComponent;
}());
export { CheckboxGroupComponent };
CheckboxGroupComponent.decorators = [
    { type: Component, args: [{
                selector: 're-checkbox-group',
                template: "\n    <div [ngClass]=\"{'checkbox-inline': inline, 'checkbox': !inline}\" *ngFor=\"let item of options\">\n      <label>\n        <input #checkbox type=\"checkbox\" [checked]=\"isChecked(item)\" [disabled]=\"disabled\"\n               (change)=\"onCheckBoxChange(item, checkbox)\">{{formatter(item)}}\n      </label>\n    </div>\n  ",
                styles: ["\n    :host{display:block}.checkbox-inline label{font-weight:normal}\n  "],
                changeDetection: ChangeDetectionStrategy.OnPush,
                exportAs: 'checkboxGroup',
                host: { '[class]': 'cssClass' },
                providers: [{
                        provide: NG_VALUE_ACCESSOR,
                        useExisting: forwardRef(function () { return CheckboxGroupComponent; }),
                        multi: true
                    }]
            },] },
];
/** @nocollapse */
CheckboxGroupComponent.ctorParameters = function () { return [
    { type: RebirthNGConfig, },
    { type: ChangeDetectorRef, },
]; };
CheckboxGroupComponent.propDecorators = {
    'disabled': [{ type: Input },],
    'options': [{ type: Input },],
    'inline': [{ type: Input },],
    'cssClass': [{ type: Input },],
    'formatter': [{ type: Input },],
    'valueParser': [{ type: Input },],
};
//# sourceMappingURL=checkbox-group.component.js.map