import { Directive, HostListener, Output, Input, EventEmitter, Renderer2, ElementRef, } from '@angular/core';
import { stopPropagationIfExist } from '../utils/dom-utils';
var DropdownDirective = (function () {
    function DropdownDirective(elementRef, renderer) {
        this.elementRef = elementRef;
        this.renderer = renderer;
        this.active = false;
        this.dropdownStatusChange = new EventEmitter();
        this.activeCss = 'open';
    }
    DropdownDirective.prototype.onDocumentClick = function () {
        this.active = false;
        this.updateHostStatus();
    };
    DropdownDirective.prototype.onHostClick = function ($event) {
        if (!this.active) {
            stopPropagationIfExist($event);
        }
        this.toggle();
    };
    DropdownDirective.prototype.toggle = function () {
        this.active = !this.active;
        this.updateHostStatus();
    };
    DropdownDirective.prototype.updateHostStatus = function () {
        this.dropdownStatusChange.emit(this.active);
        if (this.active) {
            this.renderer.addClass(this.elementRef.nativeElement, this.activeCss);
            return;
        }
        this.renderer.removeClass(this.elementRef.nativeElement, this.activeCss);
    };
    return DropdownDirective;
}());
export { DropdownDirective };
DropdownDirective.decorators = [
    { type: Directive, args: [{
                selector: '[reDropdown]',
                host: { '[class]': '"drop" + (direction?  direction : "down")' },
                exportAs: 'dropdown'
            },] },
];
/** @nocollapse */
DropdownDirective.ctorParameters = function () { return [
    { type: ElementRef, },
    { type: Renderer2, },
]; };
DropdownDirective.propDecorators = {
    'dropdownStatusChange': [{ type: Output },],
    'activeCss': [{ type: Input },],
    'direction': [{ type: Input },],
    'onDocumentClick': [{ type: HostListener, args: ['document:click', ['$event'],] },],
    'onHostClick': [{ type: HostListener, args: ['click', ['$event'],] },],
};
//# sourceMappingURL=dropdown.directive.js.map